@@ -5,7 +5,6 @@ When we import Base.metadata in the env.py file it will include all the models t
 have already been imported. To keep the env.py file clean, we import the Base.metadata in this file and then import all the
 needed models.
 """
-{% set template_infra_import = "shared.infra"|compute_base_path(template.name) %}
-from {{ general.source_name }}.{{ template_infra_import }}.persistence.sqlalchemy.base import Base
+from {{ general.source_name }}{{ "shared.infra.persistence.sqlalchemy.base" | resolve_import_path(template.name) }} import Base
 
 base = Base
\ No newline at end of file
